	import * as THREE from 'three';
	import {FontLoader} from 'three/addons/loaders/FontLoader.js';
	import {TextGeometry} from 'three/addons/geometries/TextGeometry.js';

	// fug rack
	export function fug(width=800, height=1700, depth=800) {
		const text = 'Fug';
		const fugObject = new THREE.Object3D();
		let group, textMesh, textGeo, materials;
		let size = 60;
		let textheight = 10;
		let pos = [];
		let rot = [];
		const hover = 30;
		const curveSegments = 8;
		let font;
		function insertText(isize, ipos, irot) {
			group = new THREE.Group();
			group.position.y = 100;
			fugObject.add( group );
			size = isize;
			pos = ipos;
			rot = irot;
			loadFont();
		}
		function loadFont() {
			const loader = new FontLoader();
			// https://threejs.org/examples/fonts/droid_sans_bold.typeface.json
			loader.load( './fonts/droid_sans_bold.typeface.json', function ( response ) {
				font = response;
				refreshText();
			} );
		}
		materials = [
			new THREE.MeshPhongMaterial( { color: 0x272c7d  , flatShading: true } ), // front
			new THREE.MeshPhongMaterial( { color: 0x272c7d  } ) // side
		];
		function createText() {
			textGeo = new TextGeometry(text.replace('TKLY_KG','K').replace('.01',''), {font: font, size: size, height: textheight, curveSegments: curveSegments});
			textGeo.computeBoundingBox();
			const centerOffset = - 0.5 * ( textGeo.boundingBox.max.x - textGeo.boundingBox.min.x );
			textMesh = new THREE.Mesh( textGeo, materials );
			textMesh.position.x = pos[0];
			textMesh.position.y = pos[1];
			textMesh.position.z = pos[2];
			textMesh.rotation.x = rot[0];
			textMesh.rotation.y = rot[1];
			textMesh.rotation.z = rot[2];
			group.add( textMesh );
		}
		function refreshText() {
			group.remove( textMesh );
			if ( ! text ) return;
			createText();
		}
		insertText(270, [-650,-1500,-720], [0, -Math.PI / 2, 0]);
	
		
		
		const materialGreyDark= new THREE.MeshLambertMaterial({color: 0x9d9d9d});
		const materialVeryGreyDark= new THREE.MeshLambertMaterial({color: 0x242424});
		const silvermaterial = new THREE.MeshLambertMaterial({color: 0xf0f0f0});
		const testmaterial = new THREE.MeshLambertMaterial({color: 0x00ff00});
		const greenmaterial = new THREE.MeshLambertMaterial({color: 0x095c23});
		const greenmaterial2 = new THREE.MeshLambertMaterial({color: 0x0f993b});
		const redmaterial = new THREE.MeshLambertMaterial({color: 0xab0000});
		const yellowmaterial = new THREE.MeshLambertMaterial({color: 0xcc9d02});
		const emergencymaterial = new THREE.MeshLambertMaterial({color: 0xff0000});
		const blumaterial = new THREE.MeshLambertMaterial({color: 0x272c7d});
		const whiteaterial = new THREE.MeshLambertMaterial({color: 0xdfdfe8});

		//fix FUG logo
		const fugfixgeometry = new THREE.BoxGeometry(10, 50, 460);
		const fugfixgeometrymesh = new THREE.Mesh(fugfixgeometry, blumaterial);
		fugfixgeometrymesh.position.set(-655,-1157,-310);
		fugObject.add(fugfixgeometrymesh);	
		
		//left rack
		const lrgeometry = new THREE.BoxGeometry(800, 1700, 600);
		const lrmesh = new THREE.Mesh(lrgeometry, silvermaterial);
		lrmesh.position.set(0 , 0 , -100);
		fugObject.add(lrmesh);
		
		//right rack
		const rrgeometry = new THREE.BoxGeometry(800, 1700, 600);
		const rrmesh = new THREE.Mesh(rrgeometry, silvermaterial);
		rrmesh.position.set( 0, 0 , -710);
		fugObject.add(rrmesh);		
		
		//basefug
		const basegeometry = new THREE.BoxGeometry(1050, 900, 1200);
		const basemesh = new THREE.Mesh(basegeometry, silvermaterial);
		basemesh.position.set( -130, -1320 , -400);
		fugObject.add(basemesh);			
		
		//edge lle		
		const llegeometry = new THREE.BoxGeometry(50, 1700, 50);
		const llemesh = new THREE.Mesh(llegeometry, materialGreyDark);
		llemesh.position.set( -425, 0 , -985);
		fugObject.add(llemesh);
		
		//edge lre		
		const lregeometry = new THREE.BoxGeometry(50, 1700, 50);
		const lremesh = new THREE.Mesh(lregeometry, materialGreyDark);
		lremesh.position.set( -425, 0 , -430);
		fugObject.add(lremesh);		

		//edge rle		
		const rlegeometry = new THREE.BoxGeometry(50, 1700, 50);
		const rlemesh = new THREE.Mesh(rlegeometry, materialGreyDark);
		rlemesh.position.set( -425, 0 , -370);
		fugObject.add(rlemesh);	
		
		//edge rre		
		const rregeometry = new THREE.BoxGeometry(50, 1700, 50);
		const rremesh = new THREE.Mesh(rregeometry, materialGreyDark);
		rremesh.position.set( -425, 0 , 175);
		fugObject.add(rremesh);		
		
		//edge lue		
		const luegeometry = new THREE.BoxGeometry(50, 50, 505);
		const luemesh = new THREE.Mesh(luegeometry, materialGreyDark);
		luemesh.position.set( -425, 825 , -707);
		fugObject.add(luemesh);		

		//edge lde		
		const ldegeometry = new THREE.BoxGeometry(50, 50, 505);
		const ldemesh = new THREE.Mesh(ldegeometry, materialGreyDark);
		ldemesh.position.set( -425, -830 , -707);
		fugObject.add(ldemesh);				

		//edge rue		
		const ruegeometry = new THREE.BoxGeometry(50, 50, 505);
		const ruemesh = new THREE.Mesh(ruegeometry, materialGreyDark);
		ruemesh.position.set( -425, 825 , -100);
		fugObject.add(ruemesh);			
		
		//edge rde		
		const rdegeometry = new THREE.BoxGeometry(50, 50, 505);
		const rdemesh = new THREE.Mesh(rdegeometry, materialGreyDark);
		rdemesh.position.set( -425, -825 , -100);
		fugObject.add(rdemesh);	
		
		//GreenButton
		const greenbutton = new THREE.CylinderGeometry(55, 55, 40, 15);
		const greenbuttonmesh = new THREE.Mesh(greenbutton, greenmaterial);
		greenbuttonmesh.rotateX(Math.PI * 0.5);
		greenbuttonmesh.rotateY(Math.PI * 1);
		greenbuttonmesh.rotateZ(Math.PI * 0.5);
		greenbuttonmesh.position.set(-400, 600 , -670);		
		fugObject.add(greenbuttonmesh);		
		
		//GreenLed
		const greenled = new THREE.CylinderGeometry(40, 40, 40, 15);
		const greenledmesh = new THREE.Mesh(greenled, greenmaterial2);
		greenledmesh.rotateX(Math.PI * 0.5);
		greenledmesh.rotateY(Math.PI * 1);
		greenledmesh.rotateZ(Math.PI * 0.5);
		greenledmesh.position.set(-400, 600 , -550);		
		fugObject.add(greenledmesh);			

		//RedButton
		const redbutton = new THREE.CylinderGeometry(55, 55, 40, 15);
		const redbuttonmesh = new THREE.Mesh(redbutton, redmaterial);
		redbuttonmesh.rotateX(Math.PI * 0.5);
		redbuttonmesh.rotateY(Math.PI * 1);
		redbuttonmesh.rotateZ(Math.PI * 0.5);
		redbuttonmesh.position.set(-400, 450 , -670);		
		fugObject.add(redbuttonmesh);			

		//YelloyLed
		const yellowled = new THREE.CylinderGeometry(40, 40, 40, 15);
		const yellowledmesh = new THREE.Mesh(yellowled, yellowmaterial);
		yellowledmesh.rotateX(Math.PI * 0.5);
		yellowledmesh.rotateY(Math.PI * 1);
		yellowledmesh.rotateZ(Math.PI * 0.5);
		yellowledmesh.position.set(-400, 450 , -550);		
		fugObject.add(yellowledmesh);	
		
		//EmergenctButton
		const emergencybutton = new THREE.CylinderGeometry(80, 80, 40, 15);
		const emergencybuttonmesh = new THREE.Mesh(emergencybutton, emergencymaterial);
		emergencybuttonmesh.rotateX(Math.PI * 0.5);
		emergencybuttonmesh.rotateY(Math.PI * 1);
		emergencybuttonmesh.rotateZ(Math.PI * 0.5);
		emergencybuttonmesh.position.set(-400, 270 , -620);		
		fugObject.add(emergencybuttonmesh);	
		
		//display up		
		const displayupgeometry = new THREE.BoxGeometry(50, 50, 150);
		const displayupgeometrymesh = new THREE.Mesh(displayupgeometry, materialVeryGreyDark);
		displayupgeometrymesh.position.set( -400, 600 , -850);
		fugObject.add(displayupgeometrymesh);			
		
		//display2 down		
		const displayupgeometry2 = new THREE.BoxGeometry(50, 50, 150);
		const displayupgeometrymesh2 = new THREE.Mesh(displayupgeometry2, materialVeryGreyDark);
		displayupgeometrymesh2.position.set( -400, 500 , -850);
		fugObject.add(displayupgeometrymesh2);	
		
		//switch		
		const switchgeometry = new THREE.BoxGeometry(10, 350, 200);
		const switchgeometrymesh = new THREE.Mesh(switchgeometry, materialVeryGreyDark);
		switchgeometrymesh.position.set( -400, -50 , -850);
		fugObject.add(switchgeometrymesh);	
		
		
		//Lgrid2 down	
		const grid2geometry = new THREE.BoxGeometry(10, 200, 520);
		const textureLoader2 = new THREE.TextureLoader();
		const texture2 = textureLoader2.load('./components/grid_texture.png');	
		texture2.wrapS = texture2.wrapT = THREE.RepeatWrapping;
		texture2.repeat.set(50, 1);		
		const material2 = new THREE.MeshBasicMaterial({ map: texture2 });		
		const grid2geometrymesh = new THREE.Mesh(grid2geometry, material2);
		grid2geometrymesh.rotateX(Math.PI * 1);
		grid2geometrymesh.rotateY(Math.PI * 1);
		grid2geometrymesh.rotateZ(Math.PI * 1);
		grid2geometrymesh.position.set( -400, -650 , -710);
		fugObject.add(grid2geometrymesh);	

		
		//Rgrid2 down	
		const grid4geometry = new THREE.BoxGeometry(10, 200, 520);
		const textureLoader4 = new THREE.TextureLoader();
		const texture4 = textureLoader4.load('./components/grid_texture.png');	
		texture4.wrapS = texture4.wrapT = THREE.RepeatWrapping;
		texture4.repeat.set(50, 1);		
		const material4 = new THREE.MeshBasicMaterial({ map: texture2 });		
		const grid4geometrymesh = new THREE.Mesh(grid4geometry, material2);
		grid4geometrymesh.rotateX(Math.PI * 1);
		grid4geometrymesh.rotateY(Math.PI * 1);
		grid4geometrymesh.rotateZ(Math.PI * 1);
		grid4geometrymesh.position.set( -400, -650 , -130);
		fugObject.add(grid4geometrymesh);	
		
		//drawer1		
		const drawer1geometry = new THREE.BoxGeometry(10, 220, 500);
		const drawer1geometrytrymesh = new THREE.Mesh(drawer1geometry, whiteaterial);
		drawer1geometrytrymesh.position.set( -400, 650 , -100);
		fugObject.add(drawer1geometrytrymesh);			
		
		//drawer2		
		const drawer2geometry = new THREE.BoxGeometry(10, 220, 500);
		const drawer2geometrytrymesh = new THREE.Mesh(drawer2geometry, whiteaterial);
		drawer2geometrytrymesh.position.set( -400, 400 , -100);
		fugObject.add(drawer2geometrytrymesh);	
		

		
		
		return fugObject;
	}
